==> tmaid-2.6.5.tar.gz: tmaid-2.6.5/src/abort.c <==
/*
    Text maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "abort.h"
#include "panel.h"
#include "orz/orzmdi.h"


gboolean abort_break;
GtkWidget *abort_box = NULL;


/******************************************************************************
*                                                                             *
* ja:中断ボックス関数群                                                       *
*                                                                             *
******************************************************************************/
static gint abort_focus;


/* ja:中断ボタンが押された */
static void
abort_box_clicked (GtkWidget *widget,
                   gpointer   user_data)
{
  abort_break = FALSE;
}


/*  ja:中断ボックス取得
    RET,中断ボックス                                                        */
GtkWidget *
abort_box_get_widget (void)
{
  if (!abort_box)
    {
      GtkWidget *button;

      button = gtk_button_new_from_stock (GTK_STOCK_STOP);
      g_signal_connect (G_OBJECT (button), "clicked",
                                        G_CALLBACK (abort_box_clicked), NULL);
      abort_box = gtk_hbox_new (FALSE, 0);
      gtk_box_pack_start (GTK_BOX (abort_box), button, FALSE, FALSE, 0);
    }
  return abort_box;
}


/*  ja:中断ボックス開始                                                     */
void
abort_box_start (void)
{
  abort_focus = GTK_WIDGET_HAS_FOCUS (find_entry) ? 1
              : GTK_WIDGET_HAS_FOCUS (replace_entry) ? 2 : 0;
  gtk_widget_set_sensitive (main_box, FALSE);
  gtk_widget_set_sensitive (find_box, FALSE);
  gtk_widget_show (abort_box);
  abort_break = TRUE;
}


/*  ja:中断ボックス終了                                                     */
void
abort_box_end (void)
{
  gtk_widget_set_sensitive (main_box, TRUE);
  gtk_widget_set_sensitive (find_box, TRUE);
  gtk_widget_hide (abort_box);
  switch (abort_focus)
    {
      case 1: gtk_widget_grab_focus (find_entry); break;
      case 2: gtk_widget_grab_focus (replace_entry); break;
      default:
        {
          TmaidWindow *tmaid;

          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
          if (tmaid)
            gtk_widget_grab_focus (tmaid->drawing);
        }
    }
}

==> tmaid-2.7.3.tar.gz: tmaid-2.7.3/src/abort.c <==
/*
    Text maid
    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "abort.h"
#include "panel.h"
#include "orz/orzmdi.h"


gboolean abort_break;
GtkWidget *abort_box = NULL;


/******************************************************************************
*                                                                             *
* ja:中断ボックス関数群                                                       *
*                                                                             *
******************************************************************************/
static gint abort_focus;


/* ja:中断ボタンが押された */
static void
abort_box_clicked (GtkWidget *widget,
                   gpointer   user_data)
{
  abort_break = FALSE;
}


/*  ja:中断ボックス取得
    RET,中断ボックス                                                        */
GtkWidget *
abort_box_get_widget (void)
{
  if (!abort_box)
    {
      GtkWidget *button;

      button = gtk_button_new_from_stock (GTK_STOCK_STOP);
      g_signal_connect (G_OBJECT (button), "clicked",
                                        G_CALLBACK (abort_box_clicked), NULL);
      abort_box = gtk_hbox_new (FALSE, 0);
      gtk_box_pack_start (GTK_BOX (abort_box), button, FALSE, FALSE, 0);
    }
  return abort_box;
}


/*  ja:中断ボックス開始                                                     */
void
abort_box_start (void)
{
  abort_focus = gtk_widget_has_focus (find_entry) ? 1
              : gtk_widget_has_focus (replace_entry) ? 2 : 0;
  gtk_widget_set_sensitive (main_box, FALSE);
  gtk_widget_set_sensitive (find_box, FALSE);
  gtk_widget_show (abort_box);
  abort_break = TRUE;
}


/*  ja:中断ボックス終了                                                     */
void
abort_box_end (void)
{
  gtk_widget_set_sensitive (main_box, TRUE);
  gtk_widget_set_sensitive (find_box, TRUE);
  gtk_widget_hide (abort_box);
  switch (abort_focus)
    {
      case 1: gtk_widget_grab_focus (find_entry); break;
      case 2: gtk_widget_grab_focus (replace_entry); break;
      default:
        {
          TmaidWindow *tmaid;

          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
          if (tmaid)
            gtk_widget_grab_focus (tmaid->drawing);
        }
    }
}
